#
# spec file for package python-schedule
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-schedule
Version:        1.1.0
Release:        4.1
Summary:        Job scheduling module for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/dbader/schedule
Source:         https://files.pythonhosted.org/packages/source/s/schedule/schedule-%{version}.tar.gz
# https://github.com/dbader/schedule/issues/484
Patch0:         python-schedule-no-mock.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
An in-process scheduler for periodic jobs that uses the builder
pattern for configuration. Schedule lets the user run Python functions
(or any other callable) periodically at pre-determined intervals.

%prep
%autosetup -p1 -n schedule-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_until_time: https://github.com/dbader/schedule/issues/488
%pytest -k 'not test_until_time'

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/schedule
%{python_sitelib}/schedule-%{version}*-info

%changelog
* Thu Jun 12 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Fri Mar  4 2022 pgajdos@suse.com
- disable flaky test_until_time
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- skip python 2.7 build
* Thu Sep  9 2021 Matej Cepl <mcepl@suse.com>
- Use %%autosetup macro instead
* Wed Sep  8 2021 pgajdos@suse.com
- version update to 1.1.0
  1.1.0 (2021-04-09)
  ++++++++++++++++++
  - Added @repeat() decorator. See #148. Thanks @rhagenaars!
  - Added execute .until(). See #195. Thanks @fredthomsen!
  - Added job retrieval filtered by tags using get_jobs('tag'). See #419. Thanks @skenvy!
  - Added type annotations. See #427. Thanks @martinthoma!
  - Bugfix: str() of job when there is no __name__. See #430. Thanks @biggerfisch!
  - Improved error messages. See #280, #439. Thanks @connorskees and @sosolidkk!
  - Improved logging. See #193. Thanks @zcking!
  - Documentation improvements and fix typos. See #424, #435, #436, #453, #437, #448. Thanks @ebllg!
  1.0.0 (2021-01-20)
  ++++++++++++++++++
  Depending on your configuration, the following bugfixes might change schedule's behaviour:
  - Fix: idle_seconds crashes when no jobs are scheduled. See #401. Thanks @yoonghm!
  - Fix: day.at('HH:MM:SS') where HMS=now+10s doesn't run today. See #331. Thanks @qmorek!
  - Fix: hour.at('MM:SS'), the seconds are set to 00. See #290. Thanks @eladbi!
  - Fix: Long-running jobs skip a day when they finish in the next day #404. Thanks @4379711!
  Other changes:
  - Dropped Python 2.7 and 3.5 support, added 3.8 and 3.9 support. See #409
  - Fix RecursionError when the job is passed to the do function as an arg. See #190. Thanks @connorskees!
  - Fix DeprecationWarning of 'collections'. See #296. Thanks @gaguirregabiria!
  - Replaced Travis with Github Actions for automated testing
  - Revamp and extend documentation. See #395
  - Improved tests. Thanks @connorskees and @Jamim!
  - Changed log messages to DEBUG level. Thanks @aisk!
  - added patches
    fix https://github.com/dbader/schedule/issues/484
    + python-schedule-no-mock.patch
* Tue Mar 26 2019 pgajdos@suse.com
- version update to 0.6.0
  * Make at() accept timestamps with 1 second precision (#267).
  * Introduce proper exception hierarchy (#271).
* Tue Dec 18 2018 Jan Engelhardt <jengelh@inai.de>
- Replace filler wording from description.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May 16 2018 toddrme2178@gmail.com
- Update to version 0.5.0
  * Keep partially scheduled jobs from breaking the scheduler (#125)
  * Add support for random intervals (Thanks @grampajoe and @gilbsgilbs)
- Update to version 0.4.3
  * Improve docs & clean up docstrings
- Update to version 0.4.2
  * Publish to PyPI as a universal (py2/py3) wheel
- Update to version 0.4.0
  * Add proper HTML (Sphinx) docs available at https://schedule.readthedocs.io/
  * CI builds now run against Python 2.7 and 3.5 (3.3 and 3.4 should work fine but are untested)
  * Fixed an issue with ``run_all()`` and having more than one job that deletes itself in the same iteration. Thanks @alaingilbert.
  * Add ability to tag jobs and to cancel jobs by tag. Thanks @Zerrossetto.
  * Improve schedule docs. Thanks @Zerrossetto.
  * Additional docs fixes by @fkromer and @yetingsky.
- Implement single-spec version
* Tue Jan 19 2016 hpj@urpla.net
- reduce log level from info to debug
* Tue Jan 19 2016 hpj@urpla.net
- version 0.3.2: initial build
